@@ -4,11 +4,11 @@ import re
 from tokenize_output.tokenize_output import tokenize_output
 
 _key = __xonsh__.env.get('XONTRIB_OUTPUT_SEARCH_KEY', 'f')
-
-_output_search_prefix = _key + '__'
 _add_previous_cmd_to_output = True
 _support_special_chars_in_prefix = True
 
+_output_search_prefix = _key + '__'
+
 def prev_special_char_pos(s, chars=':;+-_~=/\\{[(<>|#"\'^$%&?!.,'):
     for i in reversed(range(0, len(s))):
         if s[i] in chars:
@@ -56,7 +56,7 @@ __xonsh__.completers.move_to_end('xontrib_output_search', last=False)
 
 _color_regexp = re.compile(r'(\x9B|\x1B\[)[0-?]*[ -/]*[@-~]')
 @events.on_postcommand
-def _save_output(cmd: str, rtn: int, out: str or None, ts: list):
+def _save_output(cmd: str, rtn: int, out: str or None, ts: list, **kwargs):
     if out is not None:
         out = out.strip()
         if out:
